@@ -45,7 +45,7 @@
 #define GNC_RESPONSE_BACK    2
 
 /* Callbacks */
-void gnc_totd_dialog_response_cb (GtkDialog *dialog, gint reponse, gpointer user_data);
+void gnc_totd_dialog_response_cb (GtkDialog *dialog, gint response, gpointer user_data);
 void gnc_totd_dialog_startup_toggled_cb (GtkToggleButton *button, gpointer user_data);
 
 /* The Tips */
@@ -103,7 +103,7 @@ gnc_new_tip_number (TotdDialog *totd_dialog, gint offset)
      */
     if (tip_list[current_tip_number])
         tip_components = g_strsplit(tip_list[current_tip_number], "|", 0);
-    /* If the tip is empty, g_strisplit will return an empty list. This
+    /* If the tip is empty, g_strsplit will return an empty list. This
      * shouldn't normally happen, but make sure we don't crash just in
      * case */
     if (tip_components == NULL)
@@ -345,8 +345,8 @@ gnc_totd_dialog (GtkWindow *parent, gboolean startup)
     dialog  = GTK_WIDGET(gtk_builder_get_object (builder, "totd_dialog"));
     gtk_window_set_transient_for(GTK_WINDOW (dialog), parent);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog), "GncTotdDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog), "gnc-id-tip-of-the-day");
 
     totd_dialog = g_new0 (TotdDialog, 1);
     totd_dialog->dialog = dialog;
