@@ -42,7 +42,6 @@
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "gnc-prefs.h"
-#include "gnc-combott.h"
 #include "gnc-main-window.h"
 
 /* This static indicates the debugging module that this .o belongs to. */
@@ -432,6 +431,7 @@ gnc_gdate_in_valid_range (GDate *test_date, gboolean warn)
 
     if (warn && !ret)
     {
+            // Transators: Use your locale date format here!
         gchar *dialog_msg = _("The entered date is out of the range "
                   "01/01/1400 - 31/12/9999, resetting to this year");
         gchar *dialog_title = _("Date out of range");
@@ -486,7 +486,8 @@ gnc_handle_date_accelerator (GdkEventKey *event,
     case GDK_KEY_KP_Add:
     case GDK_KEY_plus:
     case GDK_KEY_equal:
-        if (event->state & GDK_SHIFT_MASK)
+    case GDK_KEY_semicolon: // See https://bugs.gnucash.org/show_bug.cgi?id=798386
+         if (event->state & GDK_SHIFT_MASK)
             g_date_add_days (&gdate, 7);
         else if (event->state & GDK_MOD1_MASK)
             g_date_add_months (&gdate, 1);
@@ -820,57 +821,6 @@ gnc_new_book_option_display (GtkWidget *parent)
     return TRUE;
 }
 
-/* This function returns a widget for selecting a cost policy
- */
-GtkWidget *
-gnc_cost_policy_select_new (void)
-{
-    GtkWidget *cost_policy_widget = NULL;
-    GList *list_of_policies = NULL;
-
-    list_of_policies = gnc_get_valid_policy_list();
-
-    g_return_val_if_fail(g_list_length (list_of_policies) >= 0, NULL);
-    if (list_of_policies)
-    {
-        GtkListStore *store;
-        GtkTreeIter  iter;
-        const char *description;
-        const char *hintstring;
-        GList *l = NULL;
-
-        store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
-        /* Add values to the list store, entry and tooltip */
-        for (l = list_of_policies; l != NULL; l = l->next)
-        {
-            GNCPolicy *pcy = l->data;
-            description = PolicyGetDescription(pcy);
-            hintstring = PolicyGetHint(pcy);
-            gtk_list_store_append (store, &iter);
-            gtk_list_store_set
-                   (store,
-                    &iter,
-                    0,
-                    (description && *description) ? _(description) : "",
-                    1,
-                    (hintstring && *hintstring) ? _(hintstring) : "",
-                    -1);
-        }
-        g_list_free(list_of_policies);
-        /* Create the new Combo with tooltip and add the store */
-        cost_policy_widget = GTK_WIDGET(gnc_combott_new());
-        g_object_set( G_OBJECT( cost_policy_widget ),
-                      "model",
-                      GTK_TREE_MODEL(store),
-                      NULL );
-        g_object_unref(store);
-    }
-    return cost_policy_widget;
-}
-
-/* This function returns a string for the CSS 'gnc-class-negative-numbers' class,
- * the returned string must be freed
- */
 gchar*
 gnc_get_negative_color (void)
 {
