@@ -296,7 +296,7 @@ gnc_date_edit_popup (GNCDateEdit *gde)
     if (!date_was_valid)
     {
         /* No valid date. Hacky workaround: Instead of crashing we randomly choose today's date. */
-        gnc_tm_get_today_start(&mtm);
+        gnc_tm_get_today_neutral(&mtm);
     }
 
     mtm.tm_mon--;
@@ -307,7 +307,7 @@ gnc_date_edit_popup (GNCDateEdit *gde)
     if (mtm.tm_year >= 1900)
         mtm.tm_year -= 1900;
 
-    gnc_tm_set_day_start(&mtm);
+    gnc_tm_set_day_neutral(&mtm);
 
     /* Set the calendar.  */
     gtk_calendar_select_day (GTK_CALENDAR (gde->calendar), 1);
@@ -655,7 +655,7 @@ gnc_date_edit_class_init (GNCDateEditClass *klass)
                                     PROP_TIME,
                                     g_param_spec_int64("time",
                                             "Date/time (seconds)",
-                                            "Date/time represented in seconds since Januari 31st, 1970",
+                                            "Date/time represented in seconds since midnight UTC, 1 January 1970",
                                             G_MININT64,
                                             G_MAXINT64,
                                             0,
@@ -892,10 +892,7 @@ create_children (GNCDateEdit *gde)
         gtk_widget_show (GTK_WIDGET(gde->cal_label));
 
     /* Graphic for the popup button. */
-    arrow = gtk_image_new_from_icon_name ("go-down", GTK_ICON_SIZE_BUTTON);
-
-    g_signal_connect (G_OBJECT (arrow), "draw",
-                      G_CALLBACK (gnc_draw_arrow_cb), GINT_TO_POINTER(1));
+    arrow = gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_BUTTON);
 
     gtk_box_pack_start (GTK_BOX (hbox), arrow, TRUE, FALSE, 0);
     gtk_widget_show (GTK_WIDGET(arrow));
@@ -1060,11 +1057,11 @@ gnc_date_edit_get_date_internal (GNCDateEdit *gde)
 
     if (!date_was_valid)
     {
-        /* Hm... no valid date. What should we do not? As a hacky workaround we
+        /* Hm... no valid date. What should we do now? As a hacky workaround we
         revert to today's date. Alternatively we can return some value that
         signals that we don't get a valid date, but all callers of this
         function will have to check this. Alas, I'm too lazy to do this here. */
-        gnc_tm_get_today_start(&tm);
+        gnc_tm_get_today_neutral(&tm);
     }
 
     tm.tm_mon--;
@@ -1112,7 +1109,7 @@ gnc_date_edit_get_date_internal (GNCDateEdit *gde)
     }
     else
     {
-        gnc_tm_set_day_start(&tm);
+        gnc_tm_set_day_neutral(&tm);
     }
 
     tm.tm_isdst = -1;
