@@ -133,16 +133,14 @@ static void gnc_ui_to_order (OrderWindow *ow, GncOrder *order)
     gnc_suspend_gui_refresh ();
     gncOrderBeginEdit (order);
 
-    gncOrderSetID (order, gtk_editable_get_chars
-                   (GTK_EDITABLE (ow->id_entry), 0, -1));
+    gncOrderSetID (order, gtk_entry_get_text (GTK_ENTRY (ow->id_entry)));
 
     text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(ow->notes_text));
     gtk_text_buffer_get_bounds (text_buffer, &start, &end);
     text = gtk_text_buffer_get_text (text_buffer, &start, &end, FALSE);
     gncOrderSetNotes (order, text);
 
-    gncOrderSetReference (order, gtk_editable_get_chars
-                          (GTK_EDITABLE (ow->ref_entry), 0, -1));
+    gncOrderSetReference (order, gtk_entry_get_text (GTK_ENTRY (ow->ref_entry)));
 
     tt = gnc_date_edit_get_date (GNC_DATE_EDIT (ow->opened_date));
     gncOrderSetDateOpened (order, tt);
@@ -232,7 +230,8 @@ gnc_order_window_cancel_cb (GtkWidget *widget, gpointer data)
 void
 gnc_order_window_help_cb (GtkWidget *widget, gpointer data)
 {
-    gnc_gnome_help(HF_HELP, HL_USAGE_BILL);
+    OrderWindow *ow = data;
+    gnc_gnome_help (GTK_WINDOW(ow->dialog), DF_MANUAL, DL_USAGE_BILL);
 }
 
 void
@@ -874,7 +873,7 @@ gnc_order_search (GtkWindow *parent, GncOrder *start, GncOwner *owner, QofBook *
                                            ORDER_IS_CLOSED, NULL);
         params = gnc_search_param_prepend (params, _("Date Opened"), NULL, type,
                                            ORDER_OPENED, NULL);
-        params = gnc_search_param_prepend (params, _("Owner Name "), NULL, type,
+        params = gnc_search_param_prepend (params, _("Owner Name"), NULL, type,
                                            ORDER_OWNER, OWNER_NAME, NULL);
         params = gnc_search_param_prepend (params, _("Order ID"), NULL, type,
                                            ORDER_ID, NULL);
