@@ -51,8 +51,7 @@ void qof_instance_set_guid (gpointer inst, const GncGUID *guid);
 /* NW: If you want a new log_module, just define
 a unique string either in gnc-engine.h or
 locally.*/
-/*static QofLogModule log_module = GNC_MOD_IMPORT;*/
-static QofLogModule log_module = GNC_MOD_TEST;
+static QofLogModule log_module = GNC_MOD_IMPORT;
 
 /* fprintf (trans_log, "mod	guid	time_now	" \
    "date_entered	date_posted	" \
@@ -110,9 +109,7 @@ static char *olds;
    returning a 0 length valid string between two consecutive ocurence of delim.
    It will also return a 0 length string instead of NULL when it reaches the end of s
 */
-static char * my_strtok (s, delim)
-char *s;
-const char *delim;
+static char * my_strtok (char *s, const char *delim)
 {
     char *token;
     /*DEBUG("strtok(): Start...");*/
@@ -368,7 +365,6 @@ static void  process_trans_record(  FILE *log_file)
     const char * record_end_str = "===== END";
     int first_record = TRUE;
     int record_ended = FALSE;
-    int split_num = 0;
     split_record record;
     Transaction * trans = NULL;
     Split * split = NULL;
@@ -383,7 +379,6 @@ static void  process_trans_record(  FILE *log_file)
         if (read_retval != NULL &&
             strncmp(record_end_str, read_buf, strlen(record_end_str)) != 0) /* If we are not at the end of the record */
         {
-            split_num++;
             /*DEBUG("process_trans_record(): Line read: %s%s",read_buf ,"\n");*/
 
             record = interpret_split_record(g_strchomp(read_buf));
@@ -608,11 +603,10 @@ void gnc_file_log_replay (GtkWindow *parent)
             {
                 int err = errno;
                 perror("File open failed");
+                /* Translators: First argument is the filename,
+                 * second argument is the error.
+                 */
                 gnc_error_dialog(NULL,
-                                 /* Translation note:
-                                  * First argument is the filename,
-                                  * second argument is the error.
-                                  */
                                  _("Failed to open log file: %s: %s"),
                                  selected_filename,
                                  strerror(err));
@@ -641,7 +635,7 @@ void gnc_file_log_replay (GtkWindow *parent)
                         {
                             read_retval = fgets(read_buf, sizeof(read_buf), log_file);
                             /*DEBUG("Chunk read: %s",read_retval);*/
-                            if (strncmp(record_start_str, read_buf, strlen(record_start_str)) == 0) /* If a record started */
+                            if (read_retval && strncmp(record_start_str, read_buf, strlen(record_start_str)) == 0) /* If a record started */
                             {
                                 process_trans_record(log_file);
                             }
