@@ -22,14 +22,12 @@
 \********************************************************************/
 
 #include <guid.hpp>
-extern "C"
-{
 #include <config.h>
 #include <gnc-locale-utils.h>
 #include <dbi/dbi.h>
 /* For direct access to dbi data structs, sadly needed for datetime */
 #include <dbi/dbi-dev.h>
-}
+#include <cmath>
 #include <gnc-datetime.hpp>
 #include "gnc-dbisqlresult.hpp"
 #include "gnc-dbisqlconnection.hpp"
@@ -109,17 +107,19 @@ GncDbiSqlResult::IteratorImpl::get_int_at_col(const char* col) const
     return dbi_result_get_longlong (m_inst->m_dbi_result, col);
 }
 
-float
+double
 GncDbiSqlResult::IteratorImpl::get_float_at_col(const char* col) const
 {
+    constexpr double float_precision = 1000000.0;
     auto type = dbi_result_get_field_type (m_inst->m_dbi_result, col);
     auto attrs = dbi_result_get_field_attribs (m_inst->m_dbi_result, col);
     if(type != DBI_TYPE_DECIMAL ||
        (attrs & DBI_DECIMAL_SIZEMASK) != DBI_DECIMAL_SIZE4)
         throw (std::invalid_argument{"Requested float from non-float column."});
     auto locale = gnc_push_locale (LC_NUMERIC, "C");
-    auto retval =  dbi_result_get_float(m_inst->m_dbi_result, col);
+    auto interim =  dbi_result_get_float(m_inst->m_dbi_result, col);
     gnc_pop_locale (LC_NUMERIC, locale);
+    double retval = static_cast<double>(round(interim * float_precision)) / float_precision;
     return retval;
 }
 
@@ -141,7 +141,7 @@ std::string
 GncDbiSqlResult::IteratorImpl::get_string_at_col(const char* col) const
 {
     auto type = dbi_result_get_field_type (m_inst->m_dbi_result, col);
-    auto attrs = dbi_result_get_field_attribs (m_inst->m_dbi_result, col);
+    dbi_result_get_field_attribs (m_inst->m_dbi_result, col);
     if(type != DBI_TYPE_STRING)
         throw (std::invalid_argument{"Requested string from non-string column."});
     auto strval = dbi_result_get_string(m_inst->m_dbi_result, col);
@@ -157,7 +157,7 @@ GncDbiSqlResult::IteratorImpl::get_time64_at_col (const char* col) const
 {
     auto result = (dbi_result_t*) (m_inst->m_dbi_result);
     auto type = dbi_result_get_field_type (result, col);
-    auto attrs = dbi_result_get_field_attribs (result, col);
+    dbi_result_get_field_attribs (result, col);
     if (type != DBI_TYPE_DATETIME)
         throw (std::invalid_argument{"Requested time64 from non-time64 column."});
 #if HAVE_LIBDBI_TO_LONGLONG
