@@ -26,8 +26,6 @@
 
 #include <kvp-frame.hpp>
 
-extern "C"
-{
 #include <config.h>
 
 #include <sys/types.h>
@@ -50,14 +48,11 @@ extern "C"
 #include "gncInvoice.h"
     /* For version_control */
 #include <gnc-prefs.h>
-}
 /* For test_conn_index_functions */
 #include "../gnc-backend-dbi.hpp"
-extern "C"
-{
+#include "../gnc-backend-dbi.h"
 #include <unittest-support.h>
 #include <test-stuff.h>
-}
 
 #include <string>
 #include <vector>
@@ -89,13 +84,15 @@ static void
 setup (Fixture* fixture, gconstpointer pData)
 {
     gchar* url = (gchar*)pData;
-    fixture->session = qof_session_new ();
+    gnc_module_init_backend_dbi();
+    auto book = qof_book_new();
+    fixture->session = qof_session_new (book);
     /* When running distcheck the source directory is read-only, which
      * prevents creating the lock file. Force the session to get
      * around that.
      */
-    qof_session_begin (fixture->session, DBI_TEST_XML_FILENAME, TRUE,
-                       FALSE, TRUE);
+    qof_session_begin (fixture->session, DBI_TEST_XML_FILENAME,
+                       SESSION_BREAK_LOCK);
     g_assert_cmpint (qof_session_get_error (fixture->session), == ,
                      ERR_BACKEND_NO_ERR);
     qof_session_load (fixture->session, NULL);
@@ -109,17 +106,16 @@ setup (Fixture* fixture, gconstpointer pData)
 static void
 setup_memory (Fixture* fixture, gconstpointer pData)
 {
-    QofSession* session = qof_session_new ();
     gchar* url = (gchar*)pData;
-    QofBook* book;
+    auto book = qof_book_new();
+    auto session = qof_session_new (book);
     Account* root, *acct1, *acct2;
     Transaction* tx;
     Split* spl1, *spl2;
     gnc_commodity_table* table;
     gnc_commodity* currency;
 
-    session = qof_session_new ();
-    book = qof_session_get_book (session);
+    gnc_module_init_backend_dbi();
     root = gnc_book_get_root_account (book);
 
     table = gnc_commodity_table_get_table (book);
@@ -135,8 +131,8 @@ setup_memory (Fixture* fixture, gconstpointer pData)
     frame->set ({"int64-val"}, new KvpValue (INT64_C (100)));
     frame->set ({"double-val"}, new KvpValue (3.14159));
     frame->set ({"numeric-val"}, new KvpValue (gnc_numeric_zero ()));
-    frame->set ({"timespec-val"}, new KvpValue (timespec_now ()));
-    frame->set ({"string-val"}, new KvpValue ("abcdefghijklmnop"));
+    frame->set ({"time-val"}, new KvpValue (gnc_time(nullptr)));
+    frame->set ({"string-val"}, new KvpValue (g_strdup ("abcdefghijklmnop")));
     auto guid = qof_instance_get_guid (QOF_INSTANCE (acct1));
     frame->set ({"guid-val"}, new KvpValue (const_cast<GncGUID*> (guid_copy (
             guid))));
@@ -166,9 +162,10 @@ setup_memory (Fixture* fixture, gconstpointer pData)
 static void
 setup_business (Fixture* fixture, gconstpointer pData)
 {
-    QofSession* session = qof_session_new ();
+    gnc_module_init_backend_dbi ();
+    auto book = qof_book_new ();
+    auto session = qof_session_new (book);
     gchar* url = (gchar*)pData;
-    QofBook* book = qof_session_get_book (session);
     Account* root = gnc_book_get_root_account (book);
     Account* acct1;
     Account* acct2;
@@ -230,7 +227,7 @@ setup_business (Fixture* fixture, gconstpointer pData)
 
     emp = gncEmployeeCreate (book);
     gncEmployeeSetID (emp, "0001");
-    gncEmployeeSetUsername (emp, "gnucash");
+    gncEmployeeSetUsername (emp, PROJECT_NAME);
     gncEmployeeSetLanguage (emp, "english");
     gncEmployeeSetCurrency (emp, currency);
 
@@ -244,24 +241,22 @@ setup_business (Fixture* fixture, gconstpointer pData)
 static void
 destroy_database (gchar* url)
 {
-    gchar* protocol = NULL;
+    gchar* scheme = NULL;
     gchar* host = NULL;
     gchar* dbname = NULL;
     gchar* username = NULL;
     gchar* password = NULL;
-    gchar* basename = NULL;
     gint portnum = 0;
     gchar* port = NULL;
     auto pgsql = "pgsql";
     dbi_conn conn = NULL;
-    auto errfmt = "Unable to delete tables in %s: %s";
     gint fail = 0;
     dbi_result tables;
     StrVec tblnames;
 
-    gnc_uri_get_components (url, &protocol, &host, &portnum,
+    gnc_uri_get_components (url, &scheme, &host, &portnum,
                             &username, &password, &dbname);
-    if (g_strcmp0 (protocol, "postgres") == 0)
+    if (g_strcmp0 (scheme, "postgres") == 0)
 #if HAVE_LIBDBI_R
         conn = dbi_conn_new_r (pgsql, dbi_instance);
 #else
@@ -269,14 +264,14 @@ destroy_database (gchar* url)
 #endif
     else
 #if HAVE_LIBDBI_R
-        conn = dbi_conn_new_r (protocol, dbi_instance);
+        conn = dbi_conn_new_r (scheme, dbi_instance);
 #else
-        conn = dbi_conn_new (protocol);
+        conn = dbi_conn_new (scheme);
 #endif
     port = g_strdup_printf ("%d", portnum);
     if (conn == NULL)
     {
-        g_printf (errfmt, url, "failed to create connection");
+        g_printf ("delete tables in %s: failed to create connection", url);
         return;
     }
     fail = dbi_conn_set_option (conn, "host", host);
@@ -293,7 +288,7 @@ destroy_database (gchar* url)
     g_free (port);
     if (fail != 0)
     {
-        g_printf (errfmt, url, "failed to set an option");
+        g_printf ("delete tables in %s: failed to set an option", url);
         dbi_conn_close (conn);
         return;
     }
@@ -302,7 +297,7 @@ destroy_database (gchar* url)
     {
         const gchar* error;
         gint errnum = dbi_conn_error (conn, &error);
-        g_printf (errfmt, url, error);
+        g_printf ("delete tables in %s: failed to connect (error %d): %s", url, errnum, error);
         dbi_conn_close (conn);
         return;
     }
@@ -318,6 +313,7 @@ destroy_database (gchar* url)
                      std::string query{"DROP TABLE "};
                      query += table;
                      dbi_result rslt = dbi_conn_query (conn, query.c_str());
+                     dbi_result_free(rslt);
                   });
 }
 
@@ -349,6 +345,7 @@ teardown (Fixture* fixture, gconstpointer pData)
     g_free (lockfile);
     g_slist_free_full (fixture->hdlrs, test_free_log_handler);
     test_clear_error_list ();
+    gnc_module_finalize_backend_dbi();
 }
 
 #if 0 //temporarily disable test pending refactor.
@@ -377,9 +374,6 @@ test_dbi_store_and_reload (Fixture* fixture, gconstpointer pData)
 {
 
     const gchar* url = (const gchar*)pData;
-    QofSession* session_2;
-    QofSession* session_3;
-
     auto msg = "[GncDbiSqlConnection::unlock_database()] There was no lock entry in the Lock table";
     auto log_domain = nullptr;
     auto loglevel = static_cast<GLogLevelFlags> (G_LOG_LEVEL_WARNING |
@@ -391,19 +385,22 @@ test_dbi_store_and_reload (Fixture* fixture, gconstpointer pData)
         url = fixture->filename;
 
     // Save the session data
-    session_2 = qof_session_new ();
-    qof_session_begin (session_2, url, FALSE, TRUE, TRUE);
+    auto book2{qof_book_new()};
+    auto session_2 = qof_session_new (book2);
+    qof_session_begin (session_2, url, SESSION_NEW_OVERWRITE);
     g_assert (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
     qof_session_swap_data (fixture->session, session_2);
+    qof_book_mark_session_dirty (qof_session_get_book (session_2));
     qof_session_save (session_2, NULL);
     g_assert (session_2 != NULL);
     g_assert_cmpint (qof_session_get_error (session_2), == , ERR_BACKEND_NO_ERR);
 
     // Reload the session data
-    session_3 = qof_session_new ();
+    auto book3{qof_book_new()};
+    auto session_3 = qof_session_new (book3);
     g_assert (session_3 != NULL);
-    qof_session_begin (session_3, url, TRUE, FALSE, FALSE);
+    qof_session_begin (session_3, url, SESSION_READ_ONLY);
     g_assert (session_3 != NULL);
     g_assert_cmpint (qof_session_get_error (session_3), == , ERR_BACKEND_NO_ERR);
     qof_session_load (session_3, NULL);
@@ -430,8 +427,7 @@ static void
 test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
 {
     auto url = (gchar*)pData;
-    QofSession* session_1 = NULL, *session_2 = NULL;
-
+    QofSession* session_2 = nullptr; // Otherwise goto cleanup bypasses init.
     auto msg = "[GncDbiSqlConnection::unlock_database()] There was no lock entry in the Lock table";
     auto log_domain = nullptr;
     auto loglevel = static_cast<GLogLevelFlags> (G_LOG_LEVEL_WARNING |
@@ -442,8 +438,9 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         url = fixture->filename;
 
     // Load the session data
-    session_1 = qof_session_new ();
-    qof_session_begin (session_1, url, FALSE, TRUE, TRUE);
+    auto book1{qof_book_new()};
+    auto session_1 = qof_session_new (book1);
+    qof_session_begin (session_1, url, SESSION_NEW_OVERWRITE);
     if (session_1 &&
         qof_session_get_error (session_1) != ERR_BACKEND_NO_ERR)
     {
@@ -454,6 +451,7 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, session_1);
+    qof_book_mark_session_dirty (qof_session_get_book (session_1));
     qof_session_save (session_1, NULL);
     /* Do a safe save */
     qof_session_safe_save (session_1, NULL);
@@ -467,8 +465,8 @@ test_dbi_safe_save (Fixture* fixture, gconstpointer pData)
     }
     /* Destroy the session and reload it */
 
-    session_2 = qof_session_new ();
-    qof_session_begin (session_2, url, TRUE, FALSE, FALSE);
+    session_2 = qof_session_new (qof_book_new());
+    qof_session_begin (session_2, url, SESSION_READ_ONLY);
     if (session_2 &&
         qof_session_get_error (session_2) != ERR_BACKEND_NO_ERR)
     {
@@ -507,8 +505,7 @@ static void
 test_dbi_version_control (Fixture* fixture, gconstpointer pData)
 {
     auto url = (gchar*)pData;
-    QofSession* sess;
-    QofBook* book;
+    QofBook* book{qof_book_new()};
     QofBackendError err;
     gint ourversion = gnc_prefs_get_long_version ();
     GncSqlBackend* sql_be = nullptr;
@@ -516,8 +513,8 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
     // Load the session data
     if (fixture->filename)
         url = fixture->filename;
-    sess = qof_session_new ();
-    qof_session_begin (sess, url, FALSE, TRUE, TRUE);
+    auto sess = qof_session_new (nullptr);
+    qof_session_begin (sess, url, SESSION_NEW_OVERWRITE);
     if (sess && qof_session_get_error (sess) != ERR_BACKEND_NO_ERR)
     {
         g_warning ("Session Error: %d, %s", qof_session_get_error (sess),
@@ -527,6 +524,7 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
         goto cleanup;
     }
     qof_session_swap_data (fixture->session, sess);
+    qof_book_mark_session_dirty (qof_session_get_book (sess));
     qof_session_save (sess, NULL);
     sql_be = reinterpret_cast<decltype(sql_be)>(qof_session_get_backend (sess));
     book = qof_session_get_book (sess);
@@ -535,8 +533,8 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
     qof_book_commit_edit (book);
     qof_session_end (sess);
     qof_session_destroy (sess);
-    sess = qof_session_new ();
-    qof_session_begin (sess, url, TRUE, FALSE, FALSE);
+    sess = qof_session_new (qof_book_new());
+    qof_session_begin (sess, url, SESSION_READ_ONLY);
     qof_session_load (sess, NULL);
     err = qof_session_pop_error (sess);
     g_assert_cmpint (err, == , ERR_SQL_DB_TOO_OLD);
@@ -548,8 +546,8 @@ test_dbi_version_control (Fixture* fixture, gconstpointer pData)
     qof_book_commit_edit (book);
     qof_session_end (sess);
     qof_session_destroy (sess);
-    sess = qof_session_new ();
-    qof_session_begin (sess, url, TRUE, FALSE, FALSE);
+    sess = qof_session_new (qof_book_new());
+    qof_session_begin (sess, url, SESSION_READ_ONLY);
     qof_session_load (sess, NULL);
     qof_session_ensure_all_data_loaded (sess);
     err = qof_session_pop_error (sess);
@@ -567,8 +565,6 @@ cleanup:
 static void
 test_dbi_business_store_and_reload (Fixture* fixture, gconstpointer pData)
 {
-    QofSession* session_2;
-    QofSession* session_3;
     const gchar* url = (gchar*)pData;
 
     auto msg = "[GncDbiSqlConnection::unlock_database()] There was no lock entry in the Lock table";
@@ -579,14 +575,15 @@ test_dbi_business_store_and_reload (Fixture* fixture, gconstpointer pData)
     if (fixture->filename)
         url = fixture->filename;
     // Save the session data
-    session_2 = qof_session_new ();
-    qof_session_begin (session_2, url, FALSE, TRUE, TRUE);
+    auto session_2 = qof_session_new (qof_book_new());
+    qof_session_begin (session_2, url, SESSION_NEW_OVERWRITE);
     qof_session_swap_data (fixture->session, session_2);
+    qof_book_mark_session_dirty (qof_session_get_book (session_2));
     qof_session_save (session_2, NULL);
 
     // Reload the session data
-    session_3 = qof_session_new ();
-    qof_session_begin (session_3, url, TRUE, FALSE, FALSE);
+    auto session_3 = qof_session_new (qof_book_new());
+    qof_session_begin (session_3, url, SESSION_READ_ONLY);
     qof_session_load (session_3, NULL);
 
     // Compare with the original data
@@ -645,7 +642,7 @@ create_dbi_test_suite (const char* dbm_name, const char* url)
     GNC_TEST_ADD (subsuite, "version_control", Fixture, url, setup_memory,
                   test_dbi_version_control, teardown);
     GNC_TEST_ADD (subsuite, "business_store_and_reload", Fixture, url,
-                  setup_business, test_dbi_version_control, teardown);
+                  setup_business, test_dbi_business_store_and_reload, teardown);
     g_free (subsuite);
 
 }
