@@ -21,8 +21,8 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
  *******************************************************************/
-extern "C"
-{
+#include <glib.h>
+
 #include <config.h>
 #include <string.h>
 #include "AccountP.h"
@@ -30,8 +30,7 @@ extern "C"
 #include "TransactionP.h"
 #include "gnc-lot.h"
 #include "gnc-lot-p.h"
-}
-#include <glib.h>
+
 #include "gnc-xml-helper.h"
 
 #include "sixtp.h"
@@ -47,6 +46,7 @@ extern "C"
 
 #include "sixtp-dom-parsers.h"
 
+[[maybe_unused]] static const QofLogModule log_module = G_LOG_DOMAIN;
 const gchar* transaction_version_string = "2.0.0";
 
 static void
@@ -433,16 +433,6 @@ set_tran_time64 (xmlNodePtr node, Transaction * trn,
     return TRUE;
 }
 
-static inline gboolean
-set_tran_date (xmlNodePtr node, Transaction* trn,
-               void (*func) (Transaction* trn, const time64 tm))
-{
-    time64 time = dom_tree_to_time64 (node);
-    if (!dom_tree_valid_time64 (time, node->name)) time = 0;
-    func (trn, time);
-    return TRUE;
-}
-
 static gboolean
 trn_id_handler (xmlNodePtr node, gpointer trans_pdata)
 {
