@@ -115,6 +115,8 @@ const OptionAliases Aliases::c_option_aliases
     // ... replaced to …, Dec 2022
     {"Filter By...", {nullptr, "Filter By…"}},
     {"Specify date to filter by...", {nullptr, "Specify date to filter by…"}},
+    // trep-engine:
+    {"Running Balance", {nullptr, "Account Balance"}},
 };
 
 static bool
@@ -459,7 +461,10 @@ GncOptionDB::save_to_kvp(QofBook* book, bool clear_options) const noexcept
                              * have to store. */
                             kvp = new KvpValue(option.template get_value<double>());
                         else
-                            kvp = new KvpValue{g_strdup(option.template get_value<std::string>().c_str())};
+                        {
+                            auto str{option.template get_value<std::string>()};
+                            kvp = new KvpValue{g_strdup(str.c_str())};
+                        }
                         qof_book_set_option(book, kvp, &list_head);
                     }
                 });
