@@ -39,8 +39,8 @@ struct _gncBillTerm
     QofInstance     inst;
 
     /* 'visible' data fields directly manipulated by user */
-    char *          name;
-    char *          desc;
+    const char *    name;
+    const char *    desc;
     GncBillTermType type;
     gint            due_days;
     gint            disc_days;
@@ -72,13 +72,9 @@ static QofLogModule log_module = GNC_MOD_BUSINESS;
 #define _GNC_MOD_NAME        GNC_ID_BILLTERM
 
 #define SET_STR(obj, member, str) { \
-        char * tmp; \
-        \
         if (!g_strcmp0 (member, str)) return; \
         gncBillTermBeginEdit (obj); \
-        tmp = CACHE_INSERT (str); \
-        CACHE_REMOVE (member); \
-        member = tmp; \
+        CACHE_REPLACE(member, str); \
         }
 
 AS_STRING_DEC(GncBillTermType, ENUM_TERMS_TYPE)
@@ -141,7 +137,7 @@ enum
 };
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GncBillTerm, gnc_billterm, QOF_TYPE_INSTANCE);
+G_DEFINE_TYPE(GncBillTerm, gnc_billterm, QOF_TYPE_INSTANCE)
 
 static void
 gnc_billterm_init(GncBillTerm* bt)
@@ -753,15 +749,18 @@ gboolean gncBillTermIsDirty (const GncBillTerm *term)
  *
  */
 static void
-compute_monthyear (const GncBillTerm *term, Timespec post_date,
+compute_monthyear (const GncBillTerm *term, time64 post_date,
                    int *month, int *year)
 {
     int iday, imonth, iyear;
+    struct tm tm;
     int cutoff = term->cutoff;
 
     g_return_if_fail (term->type == GNC_TERM_TYPE_PROXIMO);
-
-    gnc_timespec2dmy (post_date, &iday, &imonth, &iyear);
+    gnc_localtime_r (&post_date, &tm);
+    iday = tm.tm_mday;
+    imonth = tm.tm_mon + 1;
+    iyear = tm.tm_year + 1900;
 
     if (cutoff <= 0)
         cutoff += gnc_date_get_last_mday (imonth - 1, iyear);
@@ -798,36 +797,36 @@ compute_monthyear (const GncBillTerm *term, Timespec post_date,
  * detailed explanation of proximo.
  */
 
-static Timespec
-compute_time (const GncBillTerm *term, Timespec post_date, int days)
+static time64
+compute_time (const GncBillTerm *term, time64 post_date, int days)
 {
-    Timespec res = post_date;
+    time64 res = gnc_time64_get_day_neutral (post_date);
     int day, month, year;
 
     switch (term->type)
     {
     case GNC_TERM_TYPE_DAYS:
-        res.tv_sec += (SECS_PER_DAY * days);
+        res += (SECS_PER_DAY * days);
+        res = gnc_time64_get_day_neutral (res);
         break;
     case GNC_TERM_TYPE_PROXIMO:
         compute_monthyear (term, post_date, &month, &year);
         day = gnc_date_get_last_mday (month - 1, year);
         if (days < day)
             day = days;
-        res = gnc_dmy2timespec (day, month, year);
+        res = gnc_dmy2time64_neutral (day, month, year);
         break;
     }
     return res;
 }
 
-Timespec
-gncBillTermComputeDueDate (const GncBillTerm *term, Timespec post_date)
+time64
+gncBillTermComputeDueDate (const GncBillTerm *term, time64 post_date)
 {
-    Timespec res = post_date;
-    if (!term) return res;
-
+    if (!term) return post_date;
     return compute_time (term, post_date, term->due_days);
 }
+
 /* Package-Private functions */
 
 static void _gncBillTermCreate (QofBook *book)
@@ -840,14 +839,28 @@ static void _gncBillTermCreate (QofBook *book)
     qof_book_set_data (book, _GNC_MOD_NAME, bi);
 }
 
+
+static void
+destroy_billterm_on_book_close (QofInstance *ent, gpointer data)
+{
+    GncBillTerm *term = GNC_BILLTERM(ent);
+
+    gncBillTermBeginEdit (term);
+    gncBillTermDestroy (term);
+}
+
 static void _gncBillTermDestroy (QofBook *book)
 {
     struct _book_info *bi;
+    QofCollection *col;
 
     if (!book) return;
 
     bi = qof_book_get_data (book, _GNC_MOD_NAME);
 
+    col = qof_book_get_collection (book, GNC_ID_BILLTERM);
+    qof_collection_foreach (col, destroy_billterm_on_book_close, NULL);
+
     g_list_free (bi->terms);
     g_free (bi);
 }
