@@ -30,6 +30,7 @@
 #include <config.h>
 
 #include <stdint.h>
+#include <inttypes.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <qofinstance-p.h>
@@ -50,11 +51,11 @@ struct _gncInvoice
 {
     QofInstance   inst;
 
-    char          *id;
-    char          *notes;
+    const char    *id;
+    const char    *notes;
     gboolean      active;
 
-    char          *billing_id;
+    const char    *billing_id;
     char          *printname;
     GncBillTerm   *terms;
     GList         *entries;
@@ -87,13 +88,9 @@ static QofLogModule log_module = GNC_MOD_BUSINESS;
 #define GNC_INVOICE_DOCLINK "assoc_uri" // this is the old name for the document link, kept for compatibility
 
 #define SET_STR(obj, member, str) { \
-    char * tmp; \
-    \
     if (!g_strcmp0 (member, str)) return; \
     gncInvoiceBeginEdit (obj); \
-    tmp = CACHE_INSERT (str); \
-    CACHE_REMOVE (member); \
-    member = tmp; \
+    CACHE_REPLACE (member, str); \
     }
 
 static void mark_invoice (GncInvoice *invoice);
@@ -133,7 +130,7 @@ enum
 };
 
 /* GObject Initialization */
-G_DEFINE_TYPE(GncInvoice, gnc_invoice, QOF_TYPE_INSTANCE);
+G_DEFINE_TYPE(GncInvoice, gnc_invoice, QOF_TYPE_INSTANCE)
 
 static void
 gnc_invoice_init (GncInvoice* inv)
@@ -361,6 +358,7 @@ GncInvoice *gncInvoiceCopy (const GncInvoice *from)
     qof_instance_get_kvp (QOF_INSTANCE (from), &v, 1, GNC_INVOICE_IS_CN);
     if (G_VALUE_HOLDS_INT64 (&v))
          qof_instance_set_kvp (QOF_INSTANCE (invoice), &v, 1, GNC_INVOICE_IS_CN);
+    g_value_unset (&v);
 
     invoice->terms = from->terms;
     gncBillTermIncRef (invoice->terms);
@@ -375,6 +373,8 @@ GncInvoice *gncInvoiceCopy (const GncInvoice *from)
     // Oops. Do not forget to copy the pointer to the correct currency here.
     invoice->currency = from->currency;
 
+    gncInvoiceSetDocLink (invoice, gncInvoiceGetDocLink (from));
+
     // Copy all invoice->entries
     for (node = from->entries; node; node = node->next)
     {
@@ -426,10 +426,14 @@ static void gncInvoiceFree (GncInvoice *invoice)
     g_list_free (invoice->entries);
     g_list_free (invoice->prices);
 
-    if (invoice->printname) g_free (invoice->printname);
+    if (invoice->printname)
+        g_free (invoice->printname);
 
-    if (invoice->terms)
-        gncBillTermDecRef (invoice->terms);
+    if (!qof_book_shutting_down (qof_instance_get_book (QOF_INSTANCE(invoice))))
+    {
+        if (invoice->terms)
+            gncBillTermDecRef (invoice->terms);
+    }
 
     /* qof_instance_release (&invoice->inst); */
     g_object_unref (invoice);
@@ -541,15 +545,20 @@ void gncInvoiceSetNotes (GncInvoice *invoice, const char *notes)
 void gncInvoiceSetDocLink (GncInvoice *invoice, const char *doclink)
 {
     if (!invoice || !doclink) return;
+
     gncInvoiceBeginEdit (invoice);
-    if (g_strcmp0 (doclink, "") == 0)
+
+    if (doclink[0] == '\0')
+    {
         qof_instance_set_kvp (QOF_INSTANCE (invoice), NULL, 1, GNC_INVOICE_DOCLINK);
+    }
     else
     {
         GValue v = G_VALUE_INIT;
         g_value_init (&v, G_TYPE_STRING);
-        g_value_set_string (&v, doclink);
+        g_value_set_static_string (&v, doclink);
         qof_instance_set_kvp (QOF_INSTANCE (invoice), &v, 1, GNC_INVOICE_DOCLINK);
+        g_value_unset (&v);
     }
     qof_instance_set_dirty (QOF_INSTANCE(invoice));
     gncInvoiceCommitEdit (invoice);
@@ -573,6 +582,7 @@ void gncInvoiceSetIsCreditNote (GncInvoice *invoice, gboolean credit_note)
     g_value_init (&v, G_TYPE_INT64);
     g_value_set_int64 (&v, credit_note ? 1 : 0);
     qof_instance_set_kvp (QOF_INSTANCE (invoice), &v, 1, GNC_INVOICE_IS_CN);
+    g_value_unset (&v);
     mark_invoice (invoice);
     gncInvoiceCommitEdit (invoice);
 
@@ -865,12 +875,14 @@ const char * gncInvoiceGetNotes (const GncInvoice *invoice)
 
 const char * gncInvoiceGetDocLink (const GncInvoice *invoice)
 {
-    GValue v = G_VALUE_INIT;
     if (!invoice) return NULL;
+
+    GValue v = G_VALUE_INIT;
     qof_instance_get_kvp (QOF_INSTANCE(invoice), &v, 1, GNC_INVOICE_DOCLINK);
-    if (G_VALUE_HOLDS_STRING(&v))
-         return g_value_get_string (&v);
-    return NULL;
+    const char *rv = G_VALUE_HOLDS_STRING(&v) ? g_value_get_string (&v) : NULL;
+    g_value_unset (&v);
+
+    return rv;
 }
 
 GncOwnerType gncInvoiceGetOwnerType (const GncInvoice *invoice)
@@ -915,6 +927,7 @@ static gnc_numeric gncInvoiceGetNetAndTaxesInternal (GncInvoice *invoice, gboole
 
     g_return_val_if_fail (invoice, net_total);
 
+    ENTER ("");
     /* Is the current document an invoice/credit note related to a customer or a vendor/employee ?
      * The GncEntry code needs to know to return the proper entry amounts
      */
@@ -925,7 +938,7 @@ static gnc_numeric gncInvoiceGetNetAndTaxesInternal (GncInvoice *invoice, gboole
     for (node = gncInvoiceGetEntries (invoice); node; node = node->next)
     {
         GncEntry *entry = node->data;
-        gnc_numeric value, tax;
+        gnc_numeric value;
 
         if (use_payment_type && gncEntryGetBillPayment (entry) != type)
             continue;
@@ -938,7 +951,7 @@ static gnc_numeric gncInvoiceGetNetAndTaxesInternal (GncInvoice *invoice, gboole
             if (gnc_numeric_check (value) == GNC_ERROR_OK)
                 net_total = gnc_numeric_add (net_total, value, GNC_DENOM_AUTO, GNC_HOW_DENOM_LCD);
             else
-                g_warning ("bad value in our entry");
+                PWARN ("bad value in our entry");
         }
 
         if (taxes)
@@ -963,6 +976,7 @@ static gnc_numeric gncInvoiceGetNetAndTaxesInternal (GncInvoice *invoice, gboole
         *taxes = tv_list;
     }
 
+    LEAVE ("%" PRId64 "/%" PRId64, net_total.num, net_total.denom);
     return net_total;
 }
 
@@ -972,10 +986,10 @@ static gnc_numeric gncInvoiceGetTotalInternal (GncInvoice *invoice, gboolean use
 {
     AccountValueList *taxes;
     gnc_numeric total;
-    int denom;
 
     if (!invoice) return gnc_numeric_zero ();
 
+    ENTER ("");
     total = gncInvoiceGetNetAndTaxesInternal (invoice, use_value, use_tax? &taxes : NULL, use_payment_type, type);
 
     if (use_tax)
@@ -987,6 +1001,7 @@ static gnc_numeric gncInvoiceGetTotalInternal (GncInvoice *invoice, gboolean use
                                  GNC_DENOM_AUTO, GNC_HOW_DENOM_EXACT | GNC_HOW_RND_ROUND_HALF_UP);
         gncAccountValueDestroy (taxes);
     }
+    LEAVE ("%" PRId64 "/%" PRId64, total.num, total.denom);
     return total;
 }
 
@@ -1016,7 +1031,6 @@ gnc_numeric gncInvoiceGetTotalOf (GncInvoice *invoice, GncEntryPaymentType type)
 
 AccountValueList *gncInvoiceGetTotalTaxList (GncInvoice *invoice)
 {
-    gnc_numeric unused;
     AccountValueList *taxes;
     if (!invoice) return NULL;
 
@@ -1042,6 +1056,7 @@ GList * gncInvoiceGetTypeListForOwnerType (GncOwnerType type)
         type_list = g_list_append (type_list, GINT_TO_POINTER(GNC_INVOICE_EMPL_CREDIT_NOTE));
         return type_list;
     default:
+        PWARN("Bad owner type, no invoices.");
         return NULL;
     }
 
@@ -1131,12 +1146,12 @@ gboolean gncInvoiceGetActive (const GncInvoice *invoice)
 gboolean gncInvoiceGetIsCreditNote (const GncInvoice *invoice)
 {
     GValue v = G_VALUE_INIT;
+    gboolean retval;
     if (!invoice) return FALSE;
     qof_instance_get_kvp (QOF_INSTANCE(invoice), &v, 1, GNC_INVOICE_IS_CN);
-    if (G_VALUE_HOLDS_INT64(&v) && g_value_get_int64 (&v))
-        return TRUE;
-    else
-        return FALSE;
+    retval = G_VALUE_HOLDS_INT64(&v) && g_value_get_int64 (&v);
+    g_value_unset (&v);
+    return retval;
 }
 
 
@@ -1351,6 +1366,7 @@ GHashTable *gncInvoiceGetForeignCurrencies (const GncInvoice *invoice)
     gboolean is_cn = gncInvoiceGetIsCreditNote (invoice);
     GHashTable *amt_hash = g_hash_table_new_full (g_direct_hash, g_direct_equal,
                                                   NULL, g_free);
+    ENTER ("");
 
     for (entries_iter = invoice->entries; entries_iter != NULL; entries_iter = g_list_next(entries_iter))
     {
@@ -1401,6 +1417,8 @@ GHashTable *gncInvoiceGetForeignCurrencies (const GncInvoice *invoice)
         }
         gncAccountValueDestroy (tt_amts);
     }
+
+    LEAVE ("");
     return amt_hash;
 }
 
@@ -1414,6 +1432,7 @@ static gboolean gncInvoicePostAddSplit (QofBook *book,
 {
     Split *split;
 
+    ENTER ("");
     split = xaccMallocSplit (book);
     /* set action and memo? */
 
@@ -1456,6 +1475,8 @@ static gboolean gncInvoicePostAddSplit (QofBook *book,
               We can't really do anything sensible about it, and this is
                         a user-interface free zone so we can't try asking the user
               again either, have to return NULL*/
+            PERR("Multiple commodities with no price.");
+            LEAVE ("FALSE");
             return FALSE;
         }
         else
@@ -1468,6 +1489,7 @@ static gboolean gncInvoicePostAddSplit (QofBook *book,
         }
     }
 
+    LEAVE ("TRUE");
     return TRUE;
 }
 
@@ -1494,6 +1516,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     if (!invoice || !acc) return NULL;
     if (gncInvoiceIsPosted (invoice)) return NULL;
 
+    ENTER ("");
     gncInvoiceBeginEdit (invoice);
     book = qof_instance_get_book (invoice);
 
@@ -1596,6 +1619,8 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
         value = gncEntryGetBalValue (entry, TRUE, is_cust_doc);
         tax   = gncEntryGetBalTaxValue (entry, TRUE, is_cust_doc);
 
+        DEBUG ("Tax %" PRId64 "/%" PRId64 " on entry value %" PRId64 "/%" PRId64,
+               tax.num, tax.denom, value.num, value.denom);
         /* add the value for the account split */
         this_acc = (is_cust_doc ? gncEntryGetInvAccount (entry) :
                     gncEntryGetBillAccount (entry));
@@ -1614,6 +1639,8 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
                       We can't really do anything sensible about it, and this is
                       a user-interface free zone so we can't try asking the user
                       again either, have to return NULL*/
+                    PERR("Failed to add split %s", gncEntryGetDescription (entry));
+                    LEAVE ("NULL");
                     return NULL;
                 }
 
@@ -1648,12 +1675,12 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
 
             }
             else
-                g_warning ("bad value in our entry");
+                PWARN ("bad value in our entry");
         }
 
         /* check the taxes */
         if (gnc_numeric_check (tax) != GNC_ERROR_OK)
-            g_warning ("bad tax in our entry");
+            PWARN ("bad tax in our entry");
 
     } /* for */
 
@@ -1663,6 +1690,8 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     gncAccountValueDestroy (taxes);
 
     /* Iterate through the splitinfo list and generate the splits */
+    if (splitinfo)
+        PINFO ("Processing Split List");
     for (iter = splitinfo; iter; iter = iter->next)
     {
         GncAccountValue *acc_val = iter->data;
@@ -1676,6 +1705,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
               We can't really do anything sensible about it, and this is
               a user-interface free zone so we can't try asking the user
               again either, have to return NULL*/
+            PERR("Failed to add split %s, aborting accumulated splits.", memo);
             return NULL;
         }
     }
@@ -1692,6 +1722,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
         gnc_numeric to_charge_bal_amount = (is_cn ? gnc_numeric_neg (invoice->to_charge_amount)
                                             : invoice->to_charge_amount);
 
+        PINFO ("Process to_card payment split");
         /* Set memo. */
         xaccSplitSetMemo (split, _("Extra to Charge Card"));
         /* Set action based on book option */
@@ -1712,6 +1743,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     {
         Split *split = xaccMallocSplit (book);
 
+        PINFO ("Process to_card balancing split");
         /* Set memo */
         xaccSplitSetMemo (split, memo);
         /* Set action based on book option */
@@ -1750,6 +1782,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     if (autopay)
         gncInvoiceAutoApplyPayments (invoice);
 
+    LEAVE ("");
     return txn;
 }
 
@@ -1769,6 +1802,7 @@ gncInvoiceUnpost (GncInvoice *invoice, gboolean reset_tax_tables)
     lot = gncInvoiceGetPostedLot (invoice);
     g_return_val_if_fail (lot, FALSE);
 
+    ENTER ("");
     /* Destroy the Posted Transaction */
     xaccTransClearReadOnly (txn);
     xaccTransBeginEdit (txn);
@@ -1794,6 +1828,8 @@ gncInvoiceUnpost (GncInvoice *invoice, gboolean reset_tax_tables)
     // Note: make a copy of the lot list here, when splits are deleted from the lot,
     //       the original list may be destroyed by the lot code.
     lot_split_list = g_list_copy (gnc_lot_get_split_list (lot));
+    if (lot_split_list)
+        PINFO ("Recreating link transactions for remaining lots");
     for (lot_split_iter = lot_split_list; lot_split_iter; lot_split_iter = lot_split_iter->next)
     {
         Split *split = lot_split_iter->data;
@@ -1844,6 +1880,7 @@ gncInvoiceUnpost (GncInvoice *invoice, gboolean reset_tax_tables)
             else if (other_invoice)
                 qof_event_gen (QOF_INSTANCE(other_invoice), QOF_EVENT_MODIFY, NULL);
         }
+        g_list_free (lot_list);
     }
     g_list_free (lot_split_list);
 
@@ -1883,6 +1920,8 @@ gncInvoiceUnpost (GncInvoice *invoice, gboolean reset_tax_tables)
     mark_invoice (invoice);
     gncInvoiceCommitEdit (invoice);
 
+    LEAVE ("TRUE");
+
     return TRUE;
 }
 
